@@ -91,12 +91,19 @@ impl<T> OpenApiService<T> {
     /// Create the Swagger UI endpoint.
     #[must_use]
     pub fn swagger_ui(&self, absolute_uri: impl AsRef<str>) -> impl Endpoint
+    where
+        T: OpenApi,
+    {
+        create_ui_endpoint(absolute_uri.as_ref(), &self.spec())
+    }
+
+    /// Returns the OAS specification file.
+    fn spec(&self) -> String
     where
         T: OpenApi,
     {
         let mut registry = Registry::new();
         let metadata = T::meta();
-
         T::register(&mut registry);
 
         let doc = Document {
@@ -105,8 +112,7 @@ impl<T> OpenApiService<T> {
             apis: &metadata,
             registry: &registry,
         };
-        let doc_json = serde_json::to_string_pretty(&doc).unwrap();
-        create_ui_endpoint(absolute_uri.as_ref(), &doc_json)
+        serde_json::to_string_pretty(&doc).unwrap()
     }
 }
 
