@@ -69,8 +69,14 @@ pub struct MetaSchema {
     pub deprecated: bool,
     #[serde(skip_serializing_if = "Vec::is_empty")]
     pub one_of: Vec<MetaSchemaRef>,
+    #[serde(skip_serializing_if = "Vec::is_empty")]
+    pub all_of: Vec<MetaSchemaRef>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub discriminator: Option<MetaDiscriminatorObject>,
+    #[serde(skip_serializing_if = "is_false")]
+    pub read_only: bool,
+    #[serde(skip_serializing_if = "is_false")]
+    pub write_only: bool,
 
     #[serde(skip_serializing_if = "Option::is_none")]
     pub multiple_of: Option<f64>,
@@ -120,7 +126,10 @@ impl MetaSchema {
         enum_items: vec![],
         deprecated: false,
         one_of: vec![],
+        all_of: vec![],
         discriminator: None,
+        read_only: false,
+        write_only: false,
         multiple_of: None,
         maximum: None,
         exclusive_maximum: None,
@@ -147,7 +156,10 @@ impl MetaSchema {
             enum_items: vec![],
             deprecated: false,
             one_of: vec![],
+            all_of: vec![],
             discriminator: None,
+            read_only: false,
+            write_only: false,
             multiple_of: None,
             maximum: None,
             exclusive_maximum: None,
@@ -161,6 +173,64 @@ impl MetaSchema {
             unique_items: None,
         }
     }
+
+    pub fn is_empty(&self) -> bool {
+        self == &Self::ANY
+    }
+
+    pub fn merge(
+        mut self,
+        MetaSchema {
+            default,
+            read_only,
+            write_only,
+            title,
+            description,
+            multiple_of,
+            maximum,
+            exclusive_maximum,
+            minimum,
+            exclusive_minimum,
+            max_length,
+            min_length,
+            pattern,
+            max_items,
+            min_items,
+            unique_items,
+            ..
+        }: MetaSchema,
+    ) -> Self {
+        self.read_only |= read_only;
+        self.write_only |= write_only;
+
+        macro_rules! merge_optional {
+            ($($name:ident),*) => {
+                $(
+                if $name.is_some() {
+                    self.$name = $name;
+                }
+                )*
+            };
+        }
+
+        merge_optional!(
+            default,
+            title,
+            description,
+            multiple_of,
+            maximum,
+            exclusive_maximum,
+            minimum,
+            exclusive_minimum,
+            max_length,
+            min_length,
+            pattern,
+            max_items,
+            min_items,
+            unique_items
+        );
+        self
+    }
 }
 
 impl From<TypeName> for MetaSchema {
@@ -195,6 +265,23 @@ impl MetaSchemaRef {
             MetaSchemaRef::Reference(name) => name,
         }
     }
+
+    pub fn merge(self, other: MetaSchema) -> Self {
+        match self {
+            MetaSchemaRef::Inline(schema) => MetaSchemaRef::Inline(schema.merge(other)),
+            MetaSchemaRef::Reference(name) => {
+                let other = MetaSchema::ANY.merge(other);
+                if other.is_empty() {
+                    MetaSchemaRef::Reference(name)
+                } else {
+                    MetaSchemaRef::Inline(MetaSchema {
+                        all_of: vec![MetaSchemaRef::Reference(name), MetaSchemaRef::Inline(other)],
+                        ..MetaSchema::ANY
+                    })
+                }
+            }
+        }
+    }
 }
 
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Serialize)]
