@@ -1,8 +1,12 @@
 use serde_json::Value;
 
 use crate::{
+    poem::web::Field,
     registry::MetaSchemaRef,
-    types::{ParseError, ParseFromJSON, ParseFromParameter, ParseResult, ToJSON, Type, TypeName},
+    types::{
+        ParseError, ParseFromJSON, ParseFromMultipartField, ParseFromParameter, ParseResult,
+        ToJSON, Type, TypeName,
+    },
 };
 
 impl Type for bool {
@@ -37,6 +41,16 @@ impl ParseFromParameter for bool {
     }
 }
 
+#[poem::async_trait]
+impl ParseFromMultipartField for bool {
+    async fn parse_from_multipart(field: Option<Field>) -> ParseResult<Self> {
+        match field {
+            Some(field) => Ok(field.text().await?.parse()?),
+            None => Err(ParseError::expected_input()),
+        }
+    }
+}
+
 impl ToJSON for bool {
     fn to_json(&self) -> Value {
         Value::Bool(*self)
