@@ -2,8 +2,12 @@ use chrono::{DateTime, FixedOffset};
 use serde_json::Value;
 
 use crate::{
+    poem::web::Field,
     registry::MetaSchemaRef,
-    types::{ParseError, ParseFromJSON, ParseFromParameter, ParseResult, ToJSON, Type, TypeName},
+    types::{
+        ParseError, ParseFromJSON, ParseFromMultipartField, ParseFromParameter, ParseResult,
+        ToJSON, Type, TypeName,
+    },
 };
 
 impl Type for DateTime<FixedOffset> {
@@ -38,6 +42,16 @@ impl ParseFromParameter for DateTime<FixedOffset> {
     }
 }
 
+#[poem::async_trait]
+impl ParseFromMultipartField for DateTime<FixedOffset> {
+    async fn parse_from_multipart(field: Option<Field>) -> ParseResult<Self> {
+        match field {
+            Some(field) => Ok(field.text().await?.parse()?),
+            None => Err(ParseError::expected_input()),
+        }
+    }
+}
+
 impl ToJSON for DateTime<FixedOffset> {
     fn to_json(&self) -> Value {
         Value::String(self.to_rfc3339())
