@@ -1,8 +1,12 @@
+use poem::web::Field;
 use serde_json::Value;
 
 use crate::{
     registry::MetaSchemaRef,
-    types::{ParseError, ParseFromJSON, ParseFromParameter, ParseResult, ToJSON, Type, TypeName},
+    types::{
+        ParseError, ParseFromJSON, ParseFromMultipartField, ParseFromParameter, ParseResult,
+        ToJSON, Type, TypeName,
+    },
 };
 
 macro_rules! impl_type_for_integers {
@@ -52,6 +56,16 @@ macro_rules! impl_type_for_integers {
             }
         }
 
+        #[poem::async_trait]
+        impl ParseFromMultipartField for $ty {
+            async fn parse_from_multipart(field: Option<Field>) -> ParseResult<Self> {
+                match field {
+                    Some(field) => Ok(field.text().await?.parse()?),
+                    None => Err(ParseError::expected_input()),
+                }
+            }
+        }
+
         impl ToJSON for $ty {
             fn to_json(&self) -> Value {
                 Value::Number((*self).into())
