@@ -95,53 +95,3 @@ fn rename_item() {
         Value::String("delete_user".to_string())
     );
 }
-
-#[test]
-fn default() {
-    #[derive(Enum, Debug, Eq, PartialEq)]
-    #[oai(default)]
-    enum MyEnum {
-        CreateUser,
-        DeleteUser,
-    }
-
-    impl Default for MyEnum {
-        fn default() -> Self {
-            MyEnum::DeleteUser
-        }
-    }
-
-    let mut registry = Registry::new();
-    MyEnum::register(&mut registry);
-    let meta = registry.schemas.remove("MyEnum").unwrap();
-    assert_eq!(meta.ty, "MyEnum");
-    assert_eq!(meta.default, Some(json!("DELETE_USER")));
-    assert_eq!(
-        MyEnum::parse_from_json(json!(null)).unwrap(),
-        MyEnum::DeleteUser
-    );
-}
-
-#[test]
-fn default_func() {
-    #[derive(Enum, Debug, Eq, PartialEq)]
-    #[oai(default = "default_my_enum")]
-    enum MyEnum {
-        CreateUser,
-        DeleteUser,
-    }
-
-    fn default_my_enum() -> MyEnum {
-        MyEnum::DeleteUser
-    }
-
-    let mut registry = Registry::new();
-    MyEnum::register(&mut registry);
-    let meta = registry.schemas.remove("MyEnum").unwrap();
-    assert_eq!(meta.ty, "MyEnum");
-    assert_eq!(meta.default, Some(json!("DELETE_USER")));
-    assert_eq!(
-        MyEnum::parse_from_json(json!(null)).unwrap(),
-        MyEnum::DeleteUser
-    );
-}
